@@ -5,7 +5,7 @@ sentry.plugins.sentry_urls
 :copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
-
+from django.db.models import Sum
 from sentry.plugins import Plugin
 
 
@@ -19,6 +19,13 @@ class UrlsPlugin(Plugin):
 
     title = 'URLs'
 
+    def get_unique_urls(self, group):
+        return group.messagefiltervalue_set.filter(key='url')\
+           .values_list('value')\
+           .annotate(times_seen=Sum('times_seen'))\
+           .values_list('value', 'times_seen')\
+           .order_by('-times_seen')
+
     def panels(self, request, group, panel_list, **kwargs):
         panel_list.append((self.get_title(), self.get_url(group)))
         return panel_list
@@ -27,4 +34,7 @@ class UrlsPlugin(Plugin):
         return self.render('sentry/plugins/sentry_urls/index.html')
 
     def widget(self, request, group, **kwargs):
-        return self.render('sentry/plugins/sentry_urls/widget.html')
+        return self.render('sentry/plugins/sentry_urls/widget.html', {
+            'group': group,
+            'unique_urls': list(self.get_unique_urls(group)[:10]),
+        })
